function [q,wLL,wHL,kvLL,kvHL,kh] = OceExc_R;

% Output
%          q         - Horizontal exchange between layers, posetive poleward [m3/s]
%          wLL/wHL   - Vertical exchange between layers, posetive upwards [m3/s] 
%          kvLL/kvHL - Vertical diffusion [m2/s]
%          kh        - Horizontal diffusion [m2/s]

% Activate global parameters
global n aLL

% Ocean overturning, poleward in the surface layers 
% and equatorward at the ocean bottom - zero in between.
qmax  =  aLL*1.8e-8;                   
q(1)  =  qmax;      
q(n)  = -qmax;

% Upwelling/downwelling given by continuity, zero at the ocean bottom
wLL(n:-1:1) =  [0 -cumsum(q(n:-1:2))]; 
wHL(n:-1:1) =  [0  cumsum(q(n:-1:2))]; 

% kv given at layer interfaces 
kvLL(1:n-1) = 2e-5.*(1+5.5*(1-exp(-100*(1:n-1)/4000)));    
kvHL(1:n-1) = 230e-5;                                     

% Horizontal diffusion
kh   =  1.65e3;                         

return

